@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import base64
 import logging
 try:
   import json
@@ -30,7 +31,7 @@ __docformat__ = "epytext"
 LOG = logging.getLogger(__name__)
 
 API_AUTH_REALM = "Cloudera Manager"
-API_CURRENT_VERSION = 19
+API_CURRENT_VERSION = 30
 
 class ApiException(RestException):
   """
@@ -56,7 +57,8 @@ class ApiResource(Resource):
   def __init__(self, server_host, server_port=None,
                username="admin", password="admin",
                use_tls=False, version=API_CURRENT_VERSION,
-               ssl_context=None):
+               ssl_context=None, timeout=None, override_base_url=None,
+               auth_realm=API_AUTH_REALM, preemptive_auth=False):
     """
     Creates a Resource object that provides API endpoints.
 
@@ -68,6 +70,12 @@ class ApiResource(Resource):
     @param use_tls: Whether to use tls (https).
     @param version: API version.
     @param ssl_context: A custom SSL context to use for HTTPS (Python 2.7.9+)
+    @param timeout: The connection timeout in seconds to use for requests. If not specified,
+                    the global default timeout setting will be used.
+    @param override_base_url: Override base URL. Supercedes server_host, server_port,
+                              and version arguments.
+    @param auth_realm: Override the HTTP Basic Authentication realm.
+    @param preemptive_auth: Preemptively send the HTTP Basic Authentication header
     @return: Resource object referring to the root.
     """
     self._version = version
@@ -77,10 +85,22 @@ class ApiResource(Resource):
     base_url = "%s://%s:%s/api/v%s" % \
         (protocol, server_host, server_port, version)
 
+    if override_base_url:
+      base_url = override_base_url
+
+    headers = { "Content-Type" : "application/json" }
+
+    if preemptive_auth:
+      # Work around an issue where urllib2 only sends the HTTP Basic Auth header
+      # if it gets a WWW-Authenticate: Basic. If SPNEGO is enabled, CM sends a
+      # WWW-Authenticate: Negotiate, causing the API client to not authenticate.
+      auth_string = base64.b64encode("%s:%s" % (username, password))
+      headers["Authorization"] = "Basic %s" % auth_string
+
     client = HttpClient(base_url, exc_class=ApiException,
-                        ssl_context=ssl_context)
-    client.set_basic_auth(username, password, API_AUTH_REALM)
-    client.set_headers( { "Content-Type" : "application/json" } )
+                        ssl_context=ssl_context, timeout=timeout)
+    client.set_basic_auth(username, password, auth_realm)
+    client.set_headers(headers)
     Resource.__init__(self, client)
 
   @property
@@ -401,9 +421,10 @@ class ApiResource(Resource):
 
 def get_root_resource(server_host, server_port=None,
                       username="admin", password="admin",
-                      use_tls=False, version=API_CURRENT_VERSION):
+                      use_tls=False, version=API_CURRENT_VERSION,
+                      timeout=None):
   """
   See ApiResource.
   """
   return ApiResource(server_host, server_port, username, password, use_tls,
-      version)
+      version, timeout)
