@@ -1164,7 +1164,8 @@ class ApiService(BaseApiResource):
     return self._cmd('disableRmHa', data=args)
 
   def enable_oozie_ha(self, new_oozie_server_host_ids, new_oozie_server_role_names=None,
-    zk_service_name=None, load_balancer_host_port=None):
+    zk_service_name=None, load_balancer_host_port=None,
+    load_balancer_hostname=None, load_balancer_port=None, load_balancer_ssl_port=None):
     """
     Enable high availability for Oozie.
 
@@ -1176,18 +1177,36 @@ class ApiService(BaseApiResource):
     @param zk_service_name: Name of the ZooKeeper service that will be used for Oozie HA.
                             This is an optional parameter if the Oozie to ZooKeeper
                             dependency is already set.
-    @param load_balancer_host_port: Address and port of the load balancer used for Oozie HA.
+    @param load_balancer_host_port: DEPRECATED Address and port of the load balancer used for Oozie HA.
                                     This is an optional parameter if this config is already set.
+    @param load_balancer_hostname: (since v19) Address and port of the load balancer used for Oozie HA.
+                                   This is an optional parameter if this config is already set.
+    @param load_balancer_port: (since v19) HTTP port of the load balancer used for Oozie HA.
+                               This is an optional parameter if this config is already set.
+    @param load_balancer_ssl_port: (since v19) HTTPS port of the load balancer used for Oozie HA.
+                                   This is an optional parameter if this config is already set.
     @return: Reference to the submitted command.
     @since: API v6
     """
-    args = dict(
-      newOozieServerHostIds = new_oozie_server_host_ids,
-      newOozieServerRoleNames = new_oozie_server_role_names,
-      zkServiceName = zk_service_name,
-      loadBalancerHostPort = load_balancer_host_port
-    )
-    return self._cmd('oozieEnableHa', data=args, api_version=6)
+    if load_balancer_hostname:
+      args = dict(
+        newOozieServerHostIds = new_oozie_server_host_ids,
+        newOozieServerRoleNames = new_oozie_server_role_names,
+        zkServiceName = zk_service_name,
+        loadBalancerHostname = load_balancer_hostname,
+        loadBalancerPort = load_balancer_port,
+        loadBalancerSslPort = load_balancer_ssl_port
+      )
+      apiVersion = 19
+    else:
+      args = dict(
+        newOozieServerHostIds = new_oozie_server_host_ids,
+        newOozieServerRoleNames = new_oozie_server_role_names,
+        zkServiceName = zk_service_name,
+        loadBalancerHostPort = load_balancer_host_port,
+      )
+      apiVersion = 6
+    return self._cmd('oozieEnableHa', data=args, api_version=apiVersion)
 
   def disable_oozie_ha(self, active_name):
     """
@@ -1535,7 +1554,7 @@ class ApiService(BaseApiResource):
   def create_replication_schedule(self,
       start_time, end_time, interval_unit, interval, paused, arguments,
       alert_on_start=False, alert_on_success=False, alert_on_fail=False,
-      alert_on_abort=False):
+      alert_on_abort=False, name=None, description=None):
     """
     Create a new replication schedule for this service.
 
@@ -1560,14 +1579,22 @@ class ApiService(BaseApiResource):
     @param alert_on_success: whether to generate alerts when the job succeeds.
     @param alert_on_fail: whether to generate alerts when the job fails.
     @param alert_on_abort: whether to generate alerts when the job is aborted.
+    @param name: Name of the replication schedule
+    @param description: Description of the replication schedule
     @return: The newly created schedule.
     @since: API v3
     """
-    schedule = ApiReplicationSchedule(self._get_resource_root(),
-      startTime=start_time, endTime=end_time, intervalUnit=interval_unit, interval=interval,
-      paused=paused, alertOnStart=alert_on_start, alertOnSuccess=alert_on_success,
-      alertOnFail=alert_on_fail, alertOnAbort=alert_on_abort)
-
+    version = self._get_resource_root().version
+    if version >= 17:  # New fields added in 5.12
+      schedule = ApiReplicationSchedule(self._get_resource_root(),
+        startTime=start_time, endTime=end_time, intervalUnit=interval_unit, interval=interval,
+        paused=paused, alertOnStart=alert_on_start, alertOnSuccess=alert_on_success,
+        alertOnFail=alert_on_fail, alertOnAbort=alert_on_abort, displayName=name, description=description)
+    else:
+      schedule = ApiReplicationSchedule2(self._get_resource_root(),
+        startTime=start_time, endTime=end_time, intervalUnit=interval_unit, interval=interval,
+        paused=paused, alertOnStart=alert_on_start, alertOnSuccess=alert_on_success,
+        alertOnFail=alert_on_fail, alertOnAbort=alert_on_abort)
     if self.type == 'HDFS':
       if isinstance(arguments, ApiHdfsCloudReplicationArguments):
         schedule.hdfsCloudArguments = arguments
@@ -1576,9 +1603,12 @@ class ApiService(BaseApiResource):
       else:
         raise TypeError, 'Unexpected type for HDFS replication argument.'
     elif self.type == 'HIVE':
-      if not isinstance(arguments, ApiHiveReplicationArguments):
+      if isinstance(arguments, ApiHiveCloudReplicationArguments):
+        schedule.hiveCloudArguments = arguments
+      elif isinstance(arguments, ApiHiveReplicationArguments):
+        schedule.hiveArguments = arguments
+      else:
         raise TypeError, 'Unexpected type for Hive replication argument.'
-      schedule.hiveArguments = arguments
     else:
       raise TypeError, 'Replication is not supported for service type ' + self.type
 
