@@ -220,7 +220,10 @@ class BaseApiObject(object):
     JSON deserialization of values.
     """
     for k, v in attrs.iteritems():
-      attr = self._check_attr(k, allow_ro)
+      try:
+        attr = self._check_attr(k, allow_ro)
+      except AttributeError:
+        continue
       if attr and from_json:
         v = attr.from_json(self._get_resource_root(), v)
       object.__setattr__(self, k, v)
@@ -715,6 +718,7 @@ class ApiHdfsReplicationArguments(BaseApiObject):
     'replicationStrategy'       : None,
     'preserveXAttrs'            : None,
     'exclusionFilters'          : None,
+    'raiseSnapshotDiffFailures' : None,
   }
 
 class ApiHdfsCloudReplicationArguments(ApiHdfsReplicationArguments):
@@ -752,6 +756,9 @@ class ApiHdfsReplicationResult(BaseApiObject):
     'failedFiles'         : ROAttr(),
     'runAsUser'           : ROAttr(),
     'runOnSourceAsUser'   : ROAttr(),
+    'remainingTime'       : ROAttr(),
+    'throughput'          : ROAttr(),
+    'estimatedCompletionTime' : ROAttr(),
   }
 
 class ApiHiveTable(BaseApiObject):
@@ -791,8 +798,24 @@ class ApiHiveReplicationArguments(BaseApiObject):
     'hdfsArguments' : Attr(ApiHdfsReplicationArguments),
     'dryRun'        : None,
     'replicateImpalaMetadata' : None,
+    'runInvalidateMetadata'   : None,
+    'numThreads'   : None,
   }
 
+class ApiHiveCloudReplicationArguments(ApiHiveReplicationArguments):
+  @classmethod
+  def _get_attributes(cls):
+    if not cls.__dict__.has_key('_ATTRIBUTES'):
+      attrs = {
+        'sourceAccount' : None,
+        'destinationAccount' : None,
+        'cloudRootPath': None,
+        'replicationOption': None
+      }
+      attrs.update(ApiHiveReplicationArguments._get_attributes())
+      cls._ATTRIBUTES = attrs
+    return cls._ATTRIBUTES
+
 class ApiHiveReplicationResult(BaseApiObject):
   _ATTRIBUTES = {
     'tableCount'            : ROAttr(),
@@ -808,6 +831,19 @@ class ApiHiveReplicationResult(BaseApiObject):
     'runAsUser'             : ROAttr(),
     'runOnSourceAsUser'     : ROAttr(),
     'phase'                 : ROAttr(),
+    'statsAvailable'        : ROAttr(),
+    'dbProcessed'           : ROAttr(),
+    'tableProcessed'        : ROAttr(),
+    'partitionProcessed'    : ROAttr(),
+    'functionProcessed'     : ROAttr(),
+    'indexProcessed'        : ROAttr(),
+    'statsProcessed'        : ROAttr(),
+    'dbExpected'            : ROAttr(),
+    'tableExpected'         : ROAttr(),
+    'partitionExpected'     : ROAttr(),
+    'functionExpected'      : ROAttr(),
+    'indexExpected'         : ROAttr(),
+    'statsExpected'         : ROAttr(),
   }
 
 class ApiReplicationCommand(ApiCommand):
@@ -822,6 +858,27 @@ class ApiReplicationCommand(ApiCommand):
       cls._ATTRIBUTES = attrs
     return cls._ATTRIBUTES
 
+class ApiReplicationSchedule2(BaseApiObject):
+  _ATTRIBUTES = {
+    'startTime'       : Attr(datetime.datetime),
+    'endTime'         : Attr(datetime.datetime),
+    'interval'        : None,
+    'intervalUnit'    : None,
+    'paused'          : None,
+    'hdfsArguments'   : Attr(ApiHdfsReplicationArguments),
+    'hiveArguments'   : Attr(ApiHiveReplicationArguments),
+    'hdfsCloudArguments'   : Attr(ApiHdfsCloudReplicationArguments),
+    'hiveCloudArguments'   : Attr(ApiHiveCloudReplicationArguments),
+    'alertOnStart'    : None,
+    'alertOnSuccess'  : None,
+    'alertOnFail'     : None,
+    'alertOnAbort'    : None,
+    'id'              : ROAttr(),
+    'nextRun'         : ROAttr(datetime.datetime),
+    'history'         : ROAttr(ApiReplicationCommand),
+    'active'          : None
+  }
+
 class ApiReplicationSchedule(BaseApiObject):
   _ATTRIBUTES = {
     'startTime'       : Attr(datetime.datetime),
@@ -832,6 +889,7 @@ class ApiReplicationSchedule(BaseApiObject):
     'hdfsArguments'   : Attr(ApiHdfsReplicationArguments),
     'hiveArguments'   : Attr(ApiHiveReplicationArguments),
     'hdfsCloudArguments'   : Attr(ApiHdfsCloudReplicationArguments),
+    'hiveCloudArguments'   : Attr(ApiHiveCloudReplicationArguments),
     'alertOnStart'    : None,
     'alertOnSuccess'  : None,
     'alertOnFail'     : None,
@@ -839,7 +897,9 @@ class ApiReplicationSchedule(BaseApiObject):
     'id'              : ROAttr(),
     'nextRun'         : ROAttr(datetime.datetime),
     'history'         : ROAttr(ApiReplicationCommand),
-    'active'          : None
+    'active'          : None,
+    'displayName'     : None,  # Added in 5.12
+    'description'     : None   # Added in 5.12
   }
 
 class ApiHBaseSnapshotPolicyArguments(BaseApiObject):
